@@ -72,7 +72,7 @@ get_source_code <- function(x) {
   # Get the code for any input variables used in the plot
   input_code <- ""
   if (exists("input", envir = parent.frame())) {
-    input_vars <- stringr::str_extract_all(plot_code, "input\\$[[:alnum:]]*")[[1]]
+    input_vars <- stringr::str_extract_all(plot_code, "input\\$[[\\w]]*")[[1]]
     input_vars <- sub("input\\$", "", input_vars)
     input_list <- shiny::reactiveValuesToList(get("input", envir = parent.frame()))
     if (length(input_vars) > 0) {
@@ -100,8 +100,8 @@ get_source_code <- function(x) {
     }
     dep_code <- paste0(dep_code, "\n")
   }
-  
+  readdata_code <- paste0("plotdata <- read.csv('plotdata.csv')", "\n") 
   # Paste together the input variables, dependency variables, and plot code
-  full_code <- paste0(input_code, dep_code, plot_code)
+  full_code <- paste0(readdata_code,input_code, dep_code, plot_code)
   full_code
 }
\ No newline at end of file
